==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/datamigration/kotlin/outputs/MigrateSqlServerSqlDbTaskOutputTableLevelResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datamigration.kotlin.outputs

import kotlin.Double
import kotlin.String
import kotlin.Suppress

/**
 *
 * @property endedOn Migration end time
 * @property errorPrefix Wildcard string prefix to use for querying all errors of the item
 * @property id Result identifier
 * @property itemsCompletedCount Number of successfully completed items
 * @property itemsCount Number of items
 * @property objectName Name of the item
 * @property resultPrefix Wildcard string prefix to use for querying all sub-tem results of the item
 * @property resultType Result type
 * Expected value is 'TableLevelOutput'.
 * @property startedOn Migration start time
 * @property state Current state of migration
 * @property statusMessage Status message
 */
public data class MigrateSqlServerSqlDbTaskOutputTableLevelResponse(
    public val endedOn: String,
    public val errorPrefix: String,
    public val id: String,
    public val itemsCompletedCount: Double,
    public val itemsCount: Double,
    public val objectName: String,
    public val resultPrefix: String,
    public val resultType: String,
    public val startedOn: String,
    public val state: String,
    public val statusMessage: String,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.datamigration.outputs.MigrateSqlServerSqlDbTaskOutputTableLevelResponse):
            MigrateSqlServerSqlDbTaskOutputTableLevelResponse =
            MigrateSqlServerSqlDbTaskOutputTableLevelResponse(
                endedOn = javaType.endedOn(),
                errorPrefix = javaType.errorPrefix(),
                id = javaType.id(),
                itemsCompletedCount = javaType.itemsCompletedCount(),
                itemsCount = javaType.itemsCount(),
                objectName = javaType.objectName(),
                resultPrefix = javaType.resultPrefix(),
                resultType = javaType.resultType(),
                startedOn = javaType.startedOn(),
                state = javaType.state(),
                statusMessage = javaType.statusMessage(),
            )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/datamigration/kotlin/outputs/MigrateSqlServerSqlDbTaskOutputTableLevelResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datamigration.kotlin.outputs

import kotlin.Double
import kotlin.String
import kotlin.Suppress

/**
 *
 * @property endedOn Migration end time
 * @property errorPrefix Wildcard string prefix to use for querying all errors of the item
 * @property id Result identifier
 * @property itemsCompletedCount Number of successfully completed items
 * @property itemsCount Number of items
 * @property objectName Name of the item
 * @property resultPrefix Wildcard string prefix to use for querying all sub-tem results of the item
 * @property resultType Result type
 * Expected value is 'TableLevelOutput'.
 * @property startedOn Migration start time
 * @property state Current state of migration
 * @property statusMessage Status message
 */
public data class MigrateSqlServerSqlDbTaskOutputTableLevelResponse(
    public val endedOn: String,
    public val errorPrefix: String,
    public val id: String,
    public val itemsCompletedCount: Double,
    public val itemsCount: Double,
    public val objectName: String,
    public val resultPrefix: String,
    public val resultType: String,
    public val startedOn: String,
    public val state: String,
    public val statusMessage: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.datamigration.outputs.MigrateSqlServerSqlDbTaskOutputTableLevelResponse): MigrateSqlServerSqlDbTaskOutputTableLevelResponse =
            MigrateSqlServerSqlDbTaskOutputTableLevelResponse(
                endedOn = javaType.endedOn(),
                errorPrefix = javaType.errorPrefix(),
                id = javaType.id(),
                itemsCompletedCount = javaType.itemsCompletedCount(),
                itemsCount = javaType.itemsCount(),
                objectName = javaType.objectName(),
                resultPrefix = javaType.resultPrefix(),
                resultType = javaType.resultType(),
                startedOn = javaType.startedOn(),
                state = javaType.state(),
                statusMessage = javaType.statusMessage(),
            )
    }
}
